@@ -12,10 +12,10 @@ from rasa.cli.arguments import export as arguments
 from rasa.shared.constants import DOCS_URL_EVENT_BROKERS, DOCS_URL_TRACKER_STORES
 from rasa.exceptions import PublishingError
 from rasa.shared.exceptions import RasaException
+from rasa.core.brokers.pika import PikaEventBroker
 
 if typing.TYPE_CHECKING:
     from rasa.core.brokers.broker import EventBroker
-    from rasa.core.brokers.pika import PikaEventBroker
     from rasa.core.tracker_store import TrackerStore
     from rasa.core.exporter import Exporter
     from rasa.core.utils import AvailableEndpoints
@@ -143,7 +143,9 @@ def _assert_max_timestamp_is_greater_than_min_timestamp(
 
 
 def _prepare_event_broker(event_broker: "EventBroker") -> None:
-    """Sets `should_keep_unpublished_messages` flag to `False` if
+    """Prepares event broker to export tracker events.
+
+    Sets `should_keep_unpublished_messages` flag to `False` if
     `self.event_broker` is a `PikaEventBroker`.
 
     If publishing of events fails, the `PikaEventBroker` instance should not keep a
@@ -154,8 +156,6 @@ def _prepare_event_broker(event_broker: "EventBroker") -> None:
     In addition, wait until the event broker reports a `ready` state.
 
     """
-    from rasa.core.brokers.pika import PikaEventBroker
-
     if isinstance(event_broker, PikaEventBroker):
         event_broker.should_keep_unpublished_messages = False
         event_broker.raise_on_failure = True
