@@ -33,6 +33,7 @@ from rasa.utils.tensorflow.constants import (
     MODEL_CONFIDENCE,
     WEIGHT_SPARSITY,
     CONNECTION_DENSITY,
+    CHECKPOINT_MODEL,
 )
 from rasa.utils.tensorflow.callback import RasaTrainingLogger, RasaModelCheckpoint
 from rasa.utils.tensorflow.data_generator import RasaBatchDataGenerator
@@ -190,12 +191,14 @@ def update_evaluation_parameters(config: Dict[Text, Any]) -> Dict[Text, Any]:
     if config[EVAL_NUM_EPOCHS] == -1:
         config[EVAL_NUM_EPOCHS] = config[EPOCHS]
     elif config[EVAL_NUM_EPOCHS] < 1:
-        raise ValueError(
-            f"'{EVAL_NUM_EXAMPLES}' is set to "
+        raise InvalidConfigException(
+            f"'{EVAL_NUM_EPOCHS}' is set to "
             f"'{config[EVAL_NUM_EPOCHS]}'. "
-            f"Only values > 1 are allowed for this configuration value."
+            "Only values either equal to -1 or greater than 0 are allowed for this "
+            "parameter."
         )
-
+    if config[CHECKPOINT_MODEL] and config[EVAL_NUM_EXAMPLES] == 0:
+        config[CHECKPOINT_MODEL] = False
     return config
 
 
@@ -531,6 +534,43 @@ def validate_configuration_settings(component_config: Dict[Text, Any]) -> None:
     _check_loss_setting(component_config)
     _check_confidence_setting(component_config)
     _check_similarity_loss_setting(component_config)
+    _check_evaluation_setting(component_config)
+
+
+def _check_evaluation_setting(component_config: Dict[Text, Any]) -> None:
+    if (
+        EVAL_NUM_EPOCHS in component_config
+        and component_config[EVAL_NUM_EPOCHS] != -1
+        and component_config[EVAL_NUM_EPOCHS] > component_config[EPOCHS]
+    ):
+        warning = (
+            f"the value of '{EVAL_NUM_EPOCHS}' is greater than the value of '{EPOCHS}'."
+            f" No evaluation will occur."
+        )
+        if component_config[CHECKPOINT_MODEL]:
+            warning = (
+                f"You have opted to save the best model, but {warning} "
+                f"No checkpoint model will be saved."
+            )
+        rasa.shared.utils.io.raise_warning(warning)
+    if CHECKPOINT_MODEL in component_config and component_config[CHECKPOINT_MODEL]:
+        if (
+            component_config[EVAL_NUM_EPOCHS] != -1
+            and component_config[EVAL_NUM_EPOCHS] < 1
+        ):
+            rasa.shared.utils.io.raise_warning(
+                f"You have opted to save the best model, but the value of "
+                f"'{EVAL_NUM_EPOCHS}' is not -1 or greater than 0. Training will fail."
+            )
+        if (
+            EVAL_NUM_EXAMPLES in component_config
+            and component_config[EVAL_NUM_EXAMPLES] <= 0
+        ):
+            rasa.shared.utils.io.raise_warning(
+                f"You have opted to save the best model, but the value of "
+                f"'{EVAL_NUM_EXAMPLES}' is not greater than 0. No checkpoint model "
+                f"will be saved."
+            )
 
 
 def _check_confidence_setting(component_config: Dict[Text, Any]) -> None:
