@@ -197,6 +197,35 @@ class Validator:
 
         return everything_is_alright
 
+    def verify_actions_in_stories_rules(self) -> bool:
+        """Verifies that actions used in stories and rules are present in the domain."""
+        everything_is_alright = True
+        visited = set()
+
+        for story in self.story_graph.story_steps:
+            for event in story.events:
+                if not isinstance(event, ActionExecuted):
+                    continue
+
+                if not event.action_name.startswith("action_"):
+                    continue
+
+                if event.action_name in visited:
+                    # we already processed this one before, we only want to warn once
+                    continue
+
+                if event.action_name not in self.domain.action_names_or_texts:
+                    rasa.shared.utils.io.raise_warning(
+                        f"The action '{event.action_name}' is used in the '{story.block_name}' block, but it "
+                        f"is not listed in the domain file. You should add it to your "
+                        f"domain file!",
+                        docs=DOCS_URL_DOMAINS,
+                    )
+                    everything_is_alright = False
+                visited.add(event.action_name)
+
+        return everything_is_alright
+
     def verify_story_structure(
         self, ignore_warnings: bool = True, max_history: Optional[int] = None
     ) -> bool:
@@ -249,6 +278,26 @@ class Validator:
         stories_are_valid = self.verify_utterances_in_stories(ignore_warnings)
         return intents_are_valid and stories_are_valid and there_is_no_duplication
 
+    def verify_form_slots(self) -> bool:
+        """Verifies that form slots match the slot mappings in domain."""
+        domain_slot_names = [slot.name for slot in self.domain.slots]
+        everything_is_alright = True
+
+        for form in self.domain.form_names:
+            form_slots = self.domain.slot_mapping_for_form(form)
+            for slot in form_slots.keys():
+                if slot in domain_slot_names:
+                    continue
+                else:
+                    rasa.shared.utils.io.raise_warning(
+                        f"The form slot '{slot}' in form '{form}' is not present in the domain slots."
+                        f"Please add the correct slot or check for typos.",
+                        docs=DOCS_URL_DOMAINS,
+                    )
+                    everything_is_alright = False
+
+        return everything_is_alright
+
     def verify_domain_validity(self) -> bool:
         """Checks whether the domain returned by the importer is empty.
 
